==================
STUPS Meta Package
==================

.. image:: https://img.shields.io/pypi/dw/stups.svg
   :target: https://pypi.python.org/pypi/stups/
   :alt: PyPI Downloads

.. image:: https://img.shields.io/pypi/v/stups.svg
   :target: https://pypi.python.org/pypi/stups/
   :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/l/stups.svg
   :target: https://pypi.python.org/pypi/stups/
   :alt: License

Meta package to install all STUPS command line tools.

.. code-block:: bash

    $ sudo pip3 install --upgrade stups

Run the "stups" wrapper script to configure all STUPS command line tools:

.. code-block:: bash

    $ stups


Releasing
=========

.. code-block:: bash

    $ ./release.sh <NEW-VERSION>
